Constants class
This class provides utilities for handling sqflite data types when creating models.
-
For variable character length, use the
varcharmap. Specify the length as a string key.- Example:
Constants.varchar['10']will output'VARCHAR(10)'.
- Example:
-
For decimal numbers, use the
decimalmap. Specify the precision and scale as a string key in the format 'p,s'.- Example:
Constants.decimal['9,2']will output'DECIMAL(9,2)'.
- Example:
-
For data types that are always the same, use the corresponding constant value.
- Example:
Constants.integerwill output'INTEGER'.
- Example:
-
For custom data types, use the
custommap. You can add any custom data types you want.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited